.. _contribute_get_started:

Getting Started
===============

This section of the documentation is all about giving new contributors the
information they need to get stuck in with making their first contribution.
This section is broken down into a number of smaller sections with the first
section containing information that every contributor should know and is where
we recommend new contributors to start. The remaining sections are then
organised by what kind of contribution you want to make.


New Contributors - Start Here
-----------------------------

